pub async fn stage(
state: AcceptState,
_msg: PullAccept,
eff: Effects<PullAccept>,
) -> AcceptStateExpand description
Create a stage that repeatedly accepts incoming connections and notifies the manager about them.
pub async fn stage(
state: AcceptState,
_msg: PullAccept,
eff: Effects<PullAccept>,
) -> AcceptStateCreate a stage that repeatedly accepts incoming connections and notifies the manager about them.