pub struct BlockFetchInitiator { /* private fields */ }Implementations
Sourceimpl BlockFetchInitiator
impl BlockFetchInitiator
Sourcepub fn new(
muxer: StageRef<MuxMessage>,
peer: Peer,
conn_id: ConnectionId,
era_history: Arc<EraHistory>,
) -> (State, Self)
pub fn new( muxer: StageRef<MuxMessage>, peer: Peer, conn_id: ConnectionId, era_history: Arc<EraHistory>, ) -> (State, Self)
Create a new BlockFetchInitiator instance for a given peer, using a given connection. Returns the initial state and the initiator instance.
The EraHistory is needed to validate the received blocks slots and era tags.