pub enum ManagerMessage {
AddPeer(Peer),
ConnectionDied(Peer, ConnectionId, Role),
Connect(Peer),
Accepted(Peer, ConnectionId),
RemovePeer(Peer),
Listen(SocketAddr),
FetchBlocks {
peer: Peer,
from: Point,
through: Point,
cr: StageRef<Blocks>,
},
NewTip(Tip),
}Variants
AddPeer(Peer)
ConnectionDied(Peer, ConnectionId, Role)
Internal message sent from the connection stage only!
Must contain the connection ID so that we can then close the actual socket;
the peers entry could already have been removed by RemovePeer.
Connect(Peer)
Accepted(Peer, ConnectionId)
RemovePeer(Peer)
Listen(SocketAddr)
FetchBlocks
NewTip(Tip)