MuxMessage

Enum MuxMessage 

pub enum MuxMessage {
    Register {
        protocol: ProtocolId<Erased>,
        frame: Frame,
        handler: StageRef<HandlerMessage>,
        max_buffer: usize,
    },
    Buffer(ProtocolId<Erased>, usize),
    Send(ProtocolId<Erased>, NonEmptyBytes, StageRef<Sent>),
    FromNetwork(Timestamp, ProtocolId<Erased>, NonEmptyBytes),
    Written,
    WantNext(ProtocolId<Erased>),
    Terminate,
}

Variants



Register

Register the given protocol with its ID so that data will be fed into it

Note that the handler explicitly needs to request each network message by sending WantNext. This is necessary to allow proper handling of TCP simultaneous open in the handshake protocol.

Fields

protocol: ProtocolId<Erased>
frame: Frame
max_buffer: usize


Buffer(ProtocolId<Erased>, usize)

Buffer incoming data for this protocol ID up to the given limit (this should be followed by Register eventually, to then consume the data)

Setting the size to zero means that data are dropped without begin buffered and without tearing down the connection.



Send(ProtocolId<Erased>, NonEmptyBytes, StageRef<Sent>)

Send the given message on the protocol ID and notify when enqueued in TCP buffer



FromNetwork(Timestamp, ProtocolId<Erased>, NonEmptyBytes)

internal message coming from the TCP stream reader



Written

Notify that the segment has been written to the TCP stream



WantNext(ProtocolId<Erased>)

Permit the next invocation of the Protocol with data from the network.



Terminate

Reading or writing error occurred