Module protocol

Module protocol 

Structs

Erased
Initiator
Outcome
Outcome of a protocol step
ProtoSpec
ProtocolId
Responder

Enums

Input
Input to a protocol step
Inputs
An input to a miniprotocol handler stage.
Role

Constants

NETWORK_SEND_TIMEOUT
PROTO_HANDSHAKE
PROTO_N2N_BLOCK_FETCH
PROTO_N2N_CHAIN_SYNC
PROTO_N2N_KEEP_ALIVE
PROTO_N2N_PEER_SHARE
PROTO_N2N_TX_SUB

Traits

ProtocolState
This tracks only the network protocol state, reacting to local decisions (Action) or incoming network messages (WireMsg). It may emit information via the Out type.
RoleT
StageState
This tracks the stage state that is used to make decisions based on inputs from the local node (LocalIn) or incoming network messages (NetworkIn). It may emit network actions to be performed via the Action type.

Functions

miniprotocol
A miniprotocol is described using two states:
outcome

Type Aliases

Miniprotocol