ProtoSpec

Struct ProtoSpec 

pub struct ProtoSpec<State, Message, R> { /* private fields */ }

Implementations

Source

impl<State, Message, R> ProtoSpec<State, Message, R>
where State: Ord + Debug + Clone + ProtocolState<R, WireMsg = Message>, Message: Ord + Debug + Clone, R: RoleT,

pub fn init(&mut self, from: State, msg: Message, to: State)

Add a transition that can be executed by the initiator.

pub fn resp(&mut self, from: State, msg: Message, to: State)

Add a transition that can be executed by the responder.

pub fn sim_open(&mut self, from: State, msg: Message, to: State)

pub fn check( &self, initial: State, local_msg: impl Fn(&Message) -> Option<State::Action>, )

Check that the protocol implementation follows the spec.

The local_msg function turns the network message under test into a local action so that the protocol can be tested.

pub fn assert_refines<S2, R2>( &self, other: &ProtoSpec<S2, Message, R2>, surjection: impl Fn(&State) -> S2, )
where S2: Ord + Debug + Clone + ProtocolState<R2, WireMsg = Message>, R2: RoleT,

Assert that this protocol refines the other protocol.

This means that this protocol has more states than the other protocol, thus the state projection must be a surjection.