ResourceParameters

Type Alias ResourceParameters 

pub type ResourceParameters = GlobalParameters;

Aliased Type

pub struct ResourceParameters {
    pub consensus_security_param: usize,
    pub epoch_length_scale_factor: usize,
    pub active_slot_coeff_inverse: usize,
    pub max_lovelace_supply: u64,
    pub slots_per_kes_period: u64,
    pub max_kes_evolution: u8,
    pub epoch_length: usize,
    pub stability_window: Slot,
    pub randomness_stabilization_window: u64,
    pub system_start: u64,
}

Fields

consensus_security_param: usize

The maximum depth of a rollback, also known as the security parameter ‘k’. This translates down to the length of our volatile storage, containing states of the ledger which aren’t yet considered final.

epoch_length_scale_factor: usize

Multiplier applied to the CONSENSUS_SECURITY_PARAM to determine the epoch length.

active_slot_coeff_inverse: usize

Inverse of the active slot coefficient (i.e. 1/f);

max_lovelace_supply: u64

Maximum supply of Ada, in lovelace (1 Ada = 1,000,000 Lovelace)

slots_per_kes_period: u64

Number of slots for a single KES validity period.

max_kes_evolution: u8

Maximum number of KES key evolution. Combined with SLOTS_PER_KES_PERIOD, these values indicates the validity period of a KES key before a new one is required.

epoch_length: usize

Number of slots in an epoch

stability_window: Slot

Relative slot from which data of the previous epoch can be considered stable.

randomness_stabilization_window: u64

Number of slots at the end of each epoch which do NOT contribute randomness to the candidate nonce of the following epoch.

system_start: u64

POSIX time (milliseconds) of the System Start.