State

Struct State 

pub struct State { /* private fields */ }

Implementations

Source

impl State

pub fn new( conn: ConnectionId, buffer: &[(ProtocolId<Erased>, usize)], role: Role, ) -> Self

Create a new state with the given connection ID and buffering the given protocols.

Note that upon receiving the first message, the stage will start reading from the network. Any data received for unregistered protocols will lead to stage termination.

pub async fn init( &mut self, eff: &mut Effects<MuxMessage>, ) -> (&mut Muxer, &mut bool, &StageRef<NonEmptyBytes>, &StageRef<Read>)