Structs
Enums
Constants
- NETWORK_
SEND_ TIMEOUT - PROTO_
HANDSHAKE - PROTO_
N2N_ BLOCK_ FETCH - PROTO_
N2N_ CHAIN_ SYNC - PROTO_
N2N_ KEEP_ ALIVE - PROTO_
N2N_ PEER_ SHARE - PROTO_
N2N_ TX_ SUB
Traits
- Protocol
State - This tracks only the network protocol state, reacting to local decisions
(
Action) or incoming network messages (WireMsg). It may emit information via theOuttype. - RoleT
- Stage
State - This tracks the stage state that is used to make decisions based on inputs
from the local node (
LocalIn) or incoming network messages (NetworkIn). It may emit network actions to be performed via theActiontype.
Functions
- miniprotocol
- A miniprotocol is described using two states:
- outcome