pub struct ProtoSpec<State, Message, R> { /* private fields */ }Implementations
Sourceimpl<State, Message, R> ProtoSpec<State, Message, R>
impl<State, Message, R> ProtoSpec<State, Message, R>
Sourcepub fn init(&mut self, from: State, msg: Message, to: State)
pub fn init(&mut self, from: State, msg: Message, to: State)
Add a transition that can be executed by the initiator.
Sourcepub fn resp(&mut self, from: State, msg: Message, to: State)
pub fn resp(&mut self, from: State, msg: Message, to: State)
Add a transition that can be executed by the responder.
pub fn sim_open(&mut self, from: State, msg: Message, to: State)
Sourcepub fn check(
&self,
initial: State,
local_msg: impl Fn(&Message) -> Option<State::Action>,
)
pub fn check( &self, initial: State, local_msg: impl Fn(&Message) -> Option<State::Action>, )
Check that the protocol implementation follows the spec.
The local_msg function turns the network message under test
into a local action so that the protocol can be tested.
Sourcepub fn assert_refines<S2, R2>(
&self,
other: &ProtoSpec<S2, Message, R2>,
surjection: impl Fn(&State) -> S2,
)
pub fn assert_refines<S2, R2>( &self, other: &ProtoSpec<S2, Message, R2>, surjection: impl Fn(&State) -> S2, )
Assert that this protocol refines the other protocol.
This means that this protocol has more states than the other protocol, thus the state projection must be a surjection.